@@ -17,12 +17,12 @@
 
 # -- Project information -----------------------------------------------------
 
-project = 'py-moneyed'
-copyright = '2021, Kai Wu'
-author = 'Kai Wu'
+project = "py-moneyed"
+copyright = "2021, Kai Wu"
+author = "Kai Wu"
 
 # The full version, including alpha/beta/rc tags
-release = '1.2'
+release = "2.0"
 
 
 # -- General configuration ---------------------------------------------------
@@ -30,16 +30,15 @@ release = '1.2'
 # Add any Sphinx extension module names here, as strings. They can be
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
 # ones.
-extensions = [
-]
+extensions = []
 
 # Add any paths that contain templates here, relative to this directory.
-templates_path = ['_templates']
+templates_path = ["_templates"]
 
 # List of patterns, relative to source directory, that match files and
 # directories to ignore when looking for source files.
 # This pattern also affects html_static_path and html_extra_path.
-exclude_patterns = ['_build', 'Thumbs.db', '.DS_Store']
+exclude_patterns = ["_build", "Thumbs.db", ".DS_Store"]
 
 
 # -- Options for HTML output -------------------------------------------------
